package Bin::Data::1D ;
our $VERSION = '0.012' ; 
our $DATE = '2021-05-27T23:05+0900' ; 

=encoding utf8

=head1 NAME

App::Bin4TSV

=head1 SYNOPSIS

This module provides dozens of useful Unix-like commands to handle tabular text files especially TSV files.

=head1 DESCRIPTION

The included commands are as follows. 

=over 4

=item *
1. B<expskip>     ; Only shows 1st, 10th, 100th, 1000th lines and so on.

=item *
2. B<freq>        ; Counts the frequencies of each different value that appears as one line.

=back

...

=head1 SEE ALSO

=cut

1 ;
